==> onos-yang-runtime-2.2.0-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/establishsubscription/DefaultEstablishSubscriptionOutput.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.establishsubscription;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.SubscriptionResultType;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptionresponsewithhints.Result;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of establishSubscriptionOutput.
 */
public class DefaultEstablishSubscriptionOutput extends InnerModelObject implements EstablishSubscriptionOutput {
    protected SubscriptionResultType subscriptionResult;
    protected BitSet valueLeafFlags = new BitSet();
    protected Result result;

    @Override
    public SubscriptionResultType subscriptionResult() {
        return subscriptionResult;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Result result() {
        return result;
    }

    @Override
    public void subscriptionResult(SubscriptionResultType subscriptionResult) {
        valueLeafFlags.set(LeafIdentifier.SUBSCRIPTIONRESULT.getLeafIndex());
        this.subscriptionResult = subscriptionResult;
    }

    @Override
    public void result(Result result) {
        this.result = result;
    }

    @Override
    public int hashCode() {
        return Objects.hash(subscriptionResult, valueLeafFlags, result);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultEstablishSubscriptionOutput) {
            DefaultEstablishSubscriptionOutput other = (DefaultEstablishSubscriptionOutput) obj;
            return
                Objects.equals(subscriptionResult, other.subscriptionResult) &&
                Objects.equals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.equals(result, other.result);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("subscriptionResult=" + subscriptionResult)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("result=" + result)
            .toString();
    }


    /**
     * Creates an instance of defaultEstablishSubscriptionOutput.
     */
    public DefaultEstablishSubscriptionOutput() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}

==> onos-yang-runtime-2.3.1-sources.jar: org/onosproject/yang/gen/v1/yrtsubscription/yrtsubscription/establishsubscription/DefaultEstablishSubscriptionOutput.java <==
/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.establishsubscription;

import java.util.BitSet;
import java.util.Objects;
import java.util.StringJoiner;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.SubscriptionResultType;
import org.onosproject.yang.gen.v1.yrtsubscription.yrtsubscription.subscriptionresponsewithhints.Result;
import org.onosproject.yang.model.InnerModelObject;

/**
 * Represents the implementation of establishSubscriptionOutput.
 */
public class DefaultEstablishSubscriptionOutput extends InnerModelObject implements EstablishSubscriptionOutput {
    protected SubscriptionResultType subscriptionResult;
    protected BitSet valueLeafFlags = new BitSet();
    protected Result result;

    @Override
    public SubscriptionResultType subscriptionResult() {
        return subscriptionResult;
    }

    @Override
    public BitSet valueLeafFlags() {
        return valueLeafFlags;
    }

    @Override
    public Result result() {
        return result;
    }

    @Override
    public void subscriptionResult(SubscriptionResultType subscriptionResult) {
        valueLeafFlags.set(LeafIdentifier.SUBSCRIPTIONRESULT.getLeafIndex());
        this.subscriptionResult = subscriptionResult;
    }

    @Override
    public void result(Result result) {
        this.result = result;
    }

    @Override
    public int hashCode() {
        return Objects.hash(subscriptionResult, valueLeafFlags, result);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj instanceof DefaultEstablishSubscriptionOutput) {
            DefaultEstablishSubscriptionOutput other = (DefaultEstablishSubscriptionOutput) obj;
            return
                Objects.deepEquals(subscriptionResult, other.subscriptionResult) &&
                Objects.deepEquals(valueLeafFlags, other.valueLeafFlags) &&
                Objects.deepEquals(result, other.result);
        }
        return false;
    }

    @Override
    public String toString() {
        return new StringJoiner(", ", getClass().getSimpleName() +"{", "}")
            .add("subscriptionResult=" + subscriptionResult)
            .add("valueLeafFlags=" + valueLeafFlags)
            .add("result=" + result)
            .toString();
    }


    /**
     * Creates an instance of defaultEstablishSubscriptionOutput.
     */
    public DefaultEstablishSubscriptionOutput() {
    }


    @Override
    public boolean isLeafValueSet(LeafIdentifier leaf) {
        return valueLeafFlags.get(leaf.getLeafIndex());
    }

}
